.. arelle documentation master file, created by
   sphinx-quickstart on Thu Feb  9 13:20:36 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to arelle's documentation!
==================================

Contents:

.. toctree::
   :maxdepth: 4

   arelle


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


